/**
 *
 * Copyright (C) 2012 Olivier Berthier
 *                    http://www.xunil.fr
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/
/**
 * 
 */
package pModel.pRole;

import pModel.Match;
import pModel.pTerrain.Terrain;
import pModel.pTortue.Tortue;

/**
 * Class abstraite des rôles des tortues.
 * 
 * @author Olivier Berthier
 *
 */
public abstract class AbstractRole  {
	/**
	 * Tortue associé au rôle
	 */
	protected Tortue tortue;
	/**
	 * Match sur lequel la tortue joue.
	 */
	protected Match match;
	
	/**
	 * Constructeur prennant une tortue en paramètre
	 * 
	 * @param tortue
	 */
	public AbstractRole(Tortue tortue) {
		super();
		match = (Match) tortue.getModel();
		this.tortue = tortue;
	}

	/**
	 * Méthode de gestion de la balle pour le rôle
	 */
	public abstract void gestionBalle();
	/**
	 * Méthode de gestion des déplacement pour le rôle
	 * 
	 * @param terrain
	 */
	public abstract void gestionDeplacements(Terrain terrain);

	
	
	/**
	 * Retourne la tortue associée au rôle
	 * 
	 * @return the tortue
	 */
	public Tortue getTortue() {
		return tortue;
		
	}

	/**
	 * Associer aue tortue au rôle
	 * 
	 * @param tortue the tortue to set
	 */
	public void setTortue(Tortue tortue) {
		this.tortue = tortue;
	}



}
