/**
 *
 * Copyright (C) 2012 Olivier Berthier
 *                    http://www.xunil.fr
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/
/**
 * 
 */
package pModel.pRole;

import java.awt.Point;
import java.util.ArrayList;

import pModel.pEquipe.Equipe;
import pModel.pTerrain.Terrain;
import pModel.pTerrain._Zone;
import pModel.pTortue.Tortue;

/**
 * Class Attaquant :
 * Créer un Rôle Attaquant
 * 
 * @author Olivier Berthier
 *
 */
public class Attaquant extends AbstractRole {

	
	/**
	 * Constructeur du rôle
	 * @param tortue
	 */
	public Attaquant(Tortue tortue) {
		super(tortue);		
	}

	/* (non-Javadoc)
	 * @see pModel.pRole.AbstractRole#gestionBalle()
	 */
	@Override
	public void gestionBalle() {

		Tortue tortue = (Tortue) this.tortue;
		//si la balle est dans l'equipe adverse :

		if(tortue.getEquipe().getMembres().contains(match.getBalle().getTortue())){
			//System.out.println("equipe :)");
			//si la balle se trouve dans l'equipe :
			if(match.getBalle().getTortue().equals(tortue)){
				//si la tortue a la balle :
				//si le but se trouve à moins de n pixels, aller vers le but
				for(Tortue t: tortue.getEquipe().getMembres()){
					//si une tortue de l'equipe se trouve à moins de n pixels et qu'elle n'a pas de tortue advers à moins de m pixels, tenter une passe
					if(tortue.distance(t)<40){
						//System.out.println("Fait une passe");
						tortue.lancer(t);
					}
				}
			}
		}else{
			//System.out.println("adverse : "+ tortue.distance(match.getBalle()));
			//si la balle se trouve à moins de n pixels, essai d'interception
			if(tortue.distance(match.getBalle())<20){
				tortue.intercepter(match.getBalle().getTortue());
			}
			//si la balle se trouve à moins de m pixels, aller vers la balle


		}


	}

	/* (non-Javadoc)
	 * @see pModel.pRole.AbstractRole#gestionDeplacements(pModel.pTerrain.Terrain)
	 */
	@Override
	public void gestionDeplacements(Terrain terrain) {

		_Zone z = terrain.getZone(new Point(tortue.getX(),tortue.getY()));
		//si la tortue a la balle, aller vers l'embut, 
		Tortue tBalle = this.match.getBalle().getTortue();




		if(tBalle.equals(tortue)){
			//Si elle se trouve dans un embu advers, on incrémente le score de l'équipe.
			if(z.getTypeZone()==0 && tortue.getEquipe().getEmbut()!=z){
				tortue.getEquipe().incrScore();
				match.getBalle().reset((int)terrain.getCenterX(),(int)terrain.getCenterY());
			}else{
				//Aller verrs l'embut advers le plus proche
				ArrayList<Equipe> equipes = this.match.getEquipes();
				_Zone plusProche=null;
				for(Equipe e:equipes){
					if(e.getEmbut()!=tortue.getEquipe().getEmbut()){
						if(plusProche==null) plusProche=e.getEmbut();
						else{
							_Zone ze = e.getEmbut();
							if(plusProche.centreGavite().distance(new Point(tortue.getX(),tortue.getY()))>ze.centreGavite().distance(new Point(tortue.getX(),tortue.getY()))){
								plusProche = ze;
							}
						}
					}
				}
				tortue.deplacementVers(plusProche.centreGavite());
				tortue.avancer(1);
			}
		}else{
			if(tortue.getEquipe().getMembres().contains(match.getBalle().getTortue())){
				//chercher à s'éloigner des autres joueurs...


				if(tortue.getEquipe().getZone().equals(z) || z.getTypeZone()==0){
					//Dans le terrain de l'equipe
					tortue.avancer(1);
				}else if(z.getTypeZone()==3 || z.getTypeZone()==2){
					//Sortie du terrain
					tortue.droite(170+(int)(Math.random() * 20));
					tortue.avancer(1);
				}else if(z.getTypeZone()==1){
					//terrains des autres equipes	
					tortue.avancer(1);					  
					//Aller vers l'embut
				}else{
					tortue.reset();
				}	 
				//tortue.avancer(1);

			}else{	
				if(Math.random()*10>5){
					tortue.deplacementVers(tBalle);
				}
				tortue.avancer(1);
			}
		}
		//sinon aller vers la balle

	}

}
