/**
 *
 * Copyright (C) 2012 Olivier Berthier
 *                    http://www.xunil.fr
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/

package pModel.pTerrain;

import java.awt.Point;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;


/**
 * Class Terrain
 * Permet de créer un terrain de jeu.
 * @author Olivier Berthier
 */
public class Terrain extends ZoneTerrain {

	//
	// Fields
	//


	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	/**
	 * Liste des zones associées au terrain
	 */
	private ArrayList<_Zone> zones = new ArrayList<_Zone>();



	//
	// Constructors
	//
	/**
	 * 
	 */
	public Terrain () { 
		super(0,0,600,400);
	};

	/**
	 * @param width
	 * @param height
	 */
	public Terrain (int width, int height) {
		super(0,0,width,height);
	};

	//
	// Methods
	//


	//
	// Accessor methods
	//

	/**
	 * Add a Zones object to the zonesVector List
	 */
	public void addZones ( _Zone new_object ) {
		zones.add(new_object);
	}



	/**
	 * Remove a Zones object from zonesVector List
	 */
	public void removeZones ( _Zone new_object )
	{
		zones.remove(new_object);
	}

	/**
	 * Get the List of Zones objects held by zonesVector
	 * @return List of Zones objects held by zonesVector
	 */
	public ArrayList<_Zone> getZonesList ( ) {
		return  zones;
	}

	/**
	 * Retourne la plus petite zone dans laquelle se trouve le point
	 *  
	 * @param p Point
	 * @return une Zone de type ZoneTerrain ou ZoneJeu
	 */
	public _Zone getZone (Point p){
		_Zone result = new ZoneTerrain(3);
		int type;
		//regarder si l'element se trouve dans un enbut, dans une zone Equipe, puis dans une zone limit (invers)
		for(type=2;type>=0;type--){
			for (Iterator<_Zone> it = this.zones.iterator();it.hasNext();) {	  
				_Zone z =  it.next();
				if(z.getTypeZone()==type){
					if(z.contains(p)) result = z;
				}			
			}
		}
		return result;
	}

	/**
	 * Trier les zones par surface (simple tri par insertion)
	 */
	public void sort(){
		int i, j;
		for (i = 1; i < this.zones.size(); ++i) {
			_Zone z = this.zones.get(i);
			for (j = i; j > 0 && this.zones.get(j-1).surface() > z.surface(); j--)
				this.zones.set(j, this.zones.get(j-1));
			this.zones.set(j, z);
		}	     
	}
	/**
	 * Inverser l'ordre du tri
	 * @see pModel.pTerrain.Terrain#sort()
	 */
	public void sortDec(){
		this.sort();
		Collections.reverse(this.zones);	  	     
	}

	/* (non-Javadoc)
	 * @see pModel.pTerrain.ZoneTerrain#toString()
	 */
	@Override 
	public String toString(){
		String result = "";
		for (Iterator<_Zone> it = this.zones.iterator();it.hasNext();) {	  
			_Zone z =  it.next();
			result+=z.toString()+" type : "+z.getTypeZone()+"\n";
		}
		return result;
	}

	//
	// Other methods
	//

}
