/**
 *
 * Copyright (C) 2012 Olivier Berthier
 *                    http://www.xunil.fr
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/

package pModel.pTerrain;

import java.awt.Point;
import java.awt.Rectangle;
import java.util.ArrayList;

import pModel.pTortue.AbstractTortue;


/**
 * Class ZoneTerrain
 * Permet de définir des zones rectangulaires sur le terrain.
 * @author Olivier Berthier
 */
public class ZoneTerrain extends Rectangle implements Comparable, _Zone {

	//
	// Fields
	//

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	//
	// Constructors
	//
	/**
	 * 1=> equipe
	 * 0=> enbut
	 * 2=> limite 
	 * 3=> sortie
	 */
	private int typeZone;

	/**
	 * Constructeur par défaut
	 */
	public ZoneTerrain () {
		super();
	};
	/**
	 * Constructeur prennant un type de zone en argument
	 * 
	 * @param typeZone
	 */
	public ZoneTerrain (int typeZone) {
		super();
		this.setTypeZone(typeZone);
	};
	/**
	 * Constructeur ZoneTerrain :
	 * 
	 * @see Rectangle#Rectangle(int, int, int, int)
	 * 
	 * @param x X minimum
	 * @param y Y minimum
	 * @param width Largeur de la zone
	 * @param height Hauteur de la zone
	 */
	public ZoneTerrain(int x, int y, int width, int height){
		super( x,  y,  width, height);
	}
	/**
	 * Constructeur ZoneTerrain :
	 * 
	 * @see Rectangle#Rectangle(int, int, int, int)
	 * 
	 * @param x X minimum
	 * @param y Y minimum
	 * @param width Largeur de la zone
	 * @param height Hauteur de la zone
	 * @param typeZone type de la zone
	 */
	public ZoneTerrain(int x, int y, int width, int height,int typeZone){
		super( x,  y,  width, height);
		this.setTypeZone(typeZone);
	}
	/**
	 * Diviser la zone en N zones
	 * 
	 * @param n 
	 * 
	 * @return Liste de ZoneTerrain
	 */
	public ArrayList<ZoneTerrain> divisionNbrZones(int n){
		// TODO
		ArrayList<ZoneTerrain> zt = new ArrayList<ZoneTerrain>();
		ZoneTerrain z1=new ZoneTerrain((int)this.getMinX(),(int)this.getMinY(),(int)(this.getWidth()/2),(int)this.getHeight());		  
		ZoneTerrain z2=new ZoneTerrain((int)(this.getMinX()+this.getWidth()/2),(int)this.getMinY(),(int)this.getWidth()/2,(int)this.getHeight());
		zt.add(z1);
		zt.add(z2);		  

		/*
		 * TODO
		    //diviser le terrain en autant de zones que d'équipes (dans un premier temps nbrEquipes doit être paire
			  int tmp,tmp1,tmp2;
			  tmp=nbrEquipes;
			  do{
				  if(tmp%2==0 && tmp>=2) tmp1=2;
				  else tmp1=1;
				  tmp/=2;
				  if(tmp%2==0 && tmp>=2) tmp2=2;
				  else tmp2=1;

			  }while(tmp>=2);
		 */

		return zt;
	}


	/**
	 * Retourne une ZoneTerrain réduction de pct pourcents de this
	 *  
	 * @param pct 
	 * @return ZoneTerrain
	 */
	public ZoneTerrain reductionPct(float pct){
		ZoneTerrain result=new ZoneTerrain();
		result=(ZoneTerrain) this.clone();
		result.setSize((int)(result.getWidth()*(1-(pct/100))),(int) (result.getHeight()*(1-(pct/100))));	  
		result.setLocation((int)(this.centreGavite().getX()-(result.getWidth()/2)), (int)(this.centreGavite().getY()-(result.getHeight()/2)) );
		return result;
	}
	/* (non-Javadoc)
	 * @see pModel.pTerrain._Zone#centreGavite()
	 */
	@Override
	public Point centreGavite(){	  
		return new Point((int)this.getCenterX(),(int)this.getCenterY());
	}
	/* (non-Javadoc)
	 * @see pModel.pTerrain._Zone#surface()
	 */
	@Override
	public double surface(){		 
		return this.getWidth()*this.getHeight();
	}

	/* (non-Javadoc)
	 * @see pModel.pTerrain._Zone#contains(pModel.pTortue.AbstractTortue)
	 */
	@Override
	public boolean contains(AbstractTortue t){
		return this.contains(t.getX(), t.getY());
	}
	//
	// Accessor methods
	//
	/* (non-Javadoc)
	 * @see pModel.pTerrain._Zone#getTypeZone()
	 */
	@Override
	public int getTypeZone() {
		return typeZone;
	}
	/* (non-Javadoc)
	 * @see pModel.pTerrain._Zone#setTypeZone(int)
	 */
	@Override
	public void setTypeZone(int typeZone) {
		this.typeZone = typeZone;
	}

	//
	// Other methods
	//

	/* (non-Javadoc)
	 * @see java.awt.Rectangle#toString()
	 */
	@Override
	public String toString(){
		return "("+this.getMinX()+";"+this.getMinY()+") ("+this.getMaxX()+";"+this.getMaxY()+") : "+this.surface();
	}
	/* (non-Javadoc)
	 * @see java.lang.Comparable#compareTo(java.lang.Object)
	 */
	@Override
	public int compareTo(Object o) {
		ZoneJeu z =(ZoneJeu) o;
		if(this.surface()>=z.surface())
			return 1;
		return 0;
	}

	/**
	 * Créer un embut par réduction de 95% de la zone
	 * @return ZoneTerrain
	 */
	public ZoneTerrain addEmbut(){
		ZoneTerrain z = this.reductionPct(95);
		z.setTypeZone(0);
		//TODO : mieux placer la zone d'embut dans la zone...
		return z;
	}
}
