/**
 *
 * Copyright (C) 2012 Olivier Berthier
 *                    http://www.xunil.fr
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/

package pModel.pTortue;

import pInclude.Observable;
import pInclude.Observer;
import pModel._Model;

/**
 * Class Balle 
 * Permet de créer une balle
 *
 * @author Olivier Berthier
 *
 */
public class Balle extends AbstractTortue implements Observable {

	//
	// Fields
	//

	/**
	 * Tortue qui a la balle
	 */
	private Tortue tortue ; 
	/**
	 * Tortue virtuelle Permet de réinitialiser la position de la balle. 
	 */
	private Tortue tortueReset;

	//
	// Constructors
	//
	/**
	 * Constructeur de Balle :
	 * 
	 * @param model Jeu dans lequel la balle est instanciée
	 */
	public Balle (_Model model) {
		super(model);
		this.tortue= new Tortue(this.model,x,y);
		this.tortueReset=tortue;

	};
	/**
	 * Constructeur de Balle
	 * @param model Jeu dans lequel la Balle est instanciée
	 * @param x Abscisse de la Balle
	 * @param y Ordonnée de la Balle
	 */
	public Balle (_Model model,int x, int y) {
		super(model,x,y);
		this.tortue= new Tortue(this.model,x,y);
		this.tortueReset=tortue;
	};
	//
	// Methods
	//

	/**
	 * Défini la position de la balle (prend les coordonnées de la tortue qui a la balle)
	 */
	public void setPosition(){
		if(this.getTortue()!=null){
			this.setX(this.getTortue().getX());
			this.setY(this.getTortue().getY());
			this.setDirection(this.getTortue().getDirection());
		}
	}

	/**
	 * Réinitiailise la Balle
	 * 
	 * @param x nouvel abscisse
	 * @param y nouvel ordonnée
	 */
	public void reset(int x, int y){
		tortueReset.setX(x);
		tortueReset.setY(y);
		this.setTortue(this.tortueReset);
	}

	//
	// Accessor methods
	//

	//
	// Other methods
	//

	/**
	 * @deprecated
	 */
	public void enregistrerObservateur(  )
	{
	}


	/**
	 * @deprecated
	 */
	public void supprimerObservateur(  )
	{
	}


	/**
	 * @deprecated
	 */
	public void notifierObservateur(  )
	{
	}


	/**
	 * @deprecated
	 */
	public void actualiserTactic(  )
	{
	}

	/* (non-Javadoc)
	 * @see pInclude.Observable#addObserver(pInclude.Observer)
	 * 
	 */
	@Override
	public void addObserver(Observer obs) {
		// TODO Auto-generated method stub

	}

	/* (non-Javadoc)
	 * @see pInclude.Observable#removeObserver()
	 */
	@Override
	public void removeObserver() {
		// TODO Auto-generated method stub

	}

	/* (non-Javadoc)
	 * @see pInclude.Observable#notifyObserver()
	 */
	@Override
	public void notifyObserver() {
		// TODO Auto-generated method stub

	}

	/**
	 * Retourne la tortue qui a la balle.
	 * @return the tortue
	 */
	public Tortue getTortue() {
		return tortue;
	}

	/**
	 * Défini la tortue qui a la balle
	 * @param tortue the tortue to set
	 */
	public void setTortue(Tortue tortue) {
		this.tortue = tortue;
	}



}
