/**
 *
 * Copyright (C) 2012 Olivier Berthier
 *                    http://www.xunil.fr
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/

package pVue;

import java.util.ArrayList;
import java.util.Iterator;

import pModel.Match;
import pModel._Model;
import pModel.pEquipe.Equipe;
import pModel.pTortue.Tortue;
import pVue.pGUI.EquipeGUI;
import pVue.pGUI.TerrainGUI;
import pVue.pGUI.pLogo.BalleLogo;
import pVue.pGUI.pLogo.EnbutLogo;
import pVue.pGUI.pLogo.TortueLogo;
import pVue.pGUI.pLogo._Logo;


/**
 * Class VueJeuEquipe
 * @author Olivier Berthier
 */
public class VueJeuEquipe implements _Vue , pInclude.Observer  {

	//
	// Fields
	//


	/**
	 * Référence du Match affiché par la Vue
	 */
	private Match model;
	/**
	 * Référence d'une instance de TerrainGUI
	 * @see pVue.pGUI.TerrainHUI 
	 */
	private TerrainGUI ft;
	/**
	 * Référencee
	 */
	private EquipeGUI fe;
	/**
	 *
	 */
	private ArrayList<_Logo> logos = new ArrayList<_Logo>();




	//
	// Constructors
	//
	/**
	 *  Constructeur de VueJeuEquipe
	 * @param model
	 */
	public VueJeuEquipe(_Model model) {
		this.model = (Match) model;
		this.initLogos();
		this.ft = new TerrainGUI(this.model.getTerrain());		
		this.fe = new EquipeGUI();		
		ft.getPanel().setLogos(this.logos);
		ft.setTitle(this.model.getTitle());
		this.ft.draw();
		this.fe.draw();
	}
	//
	// Methods
	//
	/**
	 * Destructeur de la Vue
	 */
	public void destroy(){
		ft.close();
		fe.close();
	}

	//
	// Accessor methods
	//

	/**
	 * Set the value of jeu
	 * @param newVar the new value of jeu
	 */
	public void setJeu ( Match newVar ) {
		model = newVar;
	}

	/* (non-Javadoc)
	 * @see pVue._Vue#getJeu()
	 */
	@Override
	public _Model getJeu ( ) {
		return (_Model) model;
	}

	/* (non-Javadoc)
	 * @see pVue._Vue#repaint()
	 */
	@Override
	public void repaint(){
		this.ft.getPanel().repaint();
		Equipe e = this.model.getBalle().getTortue().getEquipe();

		if(e != null)
			this.fe.updateColor(e.getCouleur());
		else this.fe.updateColor(new java.awt.Color(238, 238, 238));



		//this.fe.repaint();
	}


	/* (non-Javadoc)
	 * @see pVue._Vue#initLogos()
	 */
	@Override
	public void initLogos() {	
		if(this.model.getBalle()!=null){
			logos.add(new BalleLogo(this.model.getBalle()));
		}
		for (Iterator<Equipe> it = this.model.getEquipes().iterator();it.hasNext();) {
			Equipe e = (Equipe) it.next();
			for (Iterator<Tortue> it2 = e.getMembres().iterator();it2.hasNext();) {
				Tortue t = (Tortue) it2.next();
				logos.add(new TortueLogo(t));
			}
			logos.add(new EnbutLogo(e.getEmbut(),e.getCouleur()));
		}
	}


	/* (non-Javadoc)
	 * @see pInclude.Observer#update()
	 */
	@Override
	public void update() {
		repaint();
	}

	//
	// Other methods
	//

}
