/**
 *
 * Copyright (C) 2012 Olivier Berthier
 *                    http://www.xunil.fr
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/

package pVue.pGUI.pLogo;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Polygon;

import pModel.pTerrain.ZoneJeu;
import pModel.pTerrain.ZoneTerrain;
import pModel.pTerrain._Zone;

/**
 * Class EnbutLogo
 * Permet de définir un Logo Enbut sur un terrain de jeu.
 * @author Olivier Berthier
 *
 */
public class EnbutLogo implements _Logo {

	
	/**
	 * Instance de ZoneJeu pouvant être déssinée par l'EnbutLogo
	 */
	private ZoneJeu enbutZoneJeu;

	/**
	 * Instance de ZoneTerrain pouvant être déssinée par l'EnbutLogo
	 */
	private ZoneTerrain enbutZoneTerrain;

	/**
	 * Couleur de l'EnbutLogo
	 */
	private Color color;
	/**
	 * Constructeur d'EnbutLogo :
	 * 
	 * @param embut ZoneJeu
	 * @param color Color
	 */
	public EnbutLogo (ZoneJeu embut,Color color) {
		  this.enbutZoneJeu = embut;
		  this.enbutZoneTerrain = null;
		  this.color=color;
	 };
	 /**
	  * Constructeur d'EnbutLogo :
	  * 
	  * @param embut ZoneTerrain
	  * @param color Color
	  */
	 public EnbutLogo (ZoneTerrain embut,Color color) {
		  this.enbutZoneTerrain = embut;
		  this.enbutZoneJeu=null;
		  this.color=color;
	 };
	/**
	 * Constructeur d'EnbutLogo :
	 * 
	 * @param embut _Zone
	 * @param color Color
	 */
	public EnbutLogo(_Zone embut,Color color) {
		if(embut instanceof ZoneJeu){
			this.enbutZoneJeu = (ZoneJeu) embut;
			  this.enbutZoneTerrain = null;
		}else{
			this.enbutZoneTerrain = (ZoneTerrain) embut;
			this.enbutZoneJeu=null;
			this.color=color;
		}
	}
	/* (non-Javadoc)
	 * @see pVue.pGUI.pLogo._Logo#draw(java.awt.Graphics)
	 */
	@Override
	public void draw(Graphics graph) {
		

		Polygon but = new Polygon();
		if(enbutZoneJeu!=null){
			for(int i=0;i<enbutZoneJeu.npoints-1;i++){
				but.addPoint(enbutZoneJeu.xpoints[i], enbutZoneJeu.ypoints[i]);
			}
		}else{
			but.addPoint((int)this.enbutZoneTerrain.getMinX(), (int)this.enbutZoneTerrain.getMinY());
			but.addPoint((int)this.enbutZoneTerrain.getMinX(), (int)this.enbutZoneTerrain.getMaxY());
			but.addPoint((int)this.enbutZoneTerrain.getMaxX(), (int)this.enbutZoneTerrain.getMaxY());
			but.addPoint((int)this.enbutZoneTerrain.getMaxX(), (int)this.enbutZoneTerrain.getMinY());
		}

		graph.setColor(this.color);
		graph.drawPolygon(but);//).fillPolygon(but);
		
	}
}
