/**
 *
 * Copyright (C) 2012 Olivier Berthier
 *                    http://www.xunil.fr
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/

package pVue.pGUI.pLogo;

import java.awt.Graphics;
import java.awt.Point;
import java.awt.Polygon;

import pModel.pTortue.Tortue;


/**
 * Class LogoTortue
 * Permet de définir un Logo Tortue sur un terrain de jeu.
 * @author Olivier Berthier
 */
public class TortueLogo implements _Logo {

	//
	// Fields
	//
	// Attributs statiques	
	protected static final int rp=10, rb=5; // Taille de la pointe et de la base de la fleche
	protected static final double ratioDegRad = 0.0174533; // Rapport radians/degres (pour la conversion)
	/**
	 * Instance de Tortue déssiné par la TortueLogo 
	 */
	private Tortue tortue;
	//
	// Constructors
	//
	/**
	 * Constructeur de TortueLogo
	 * 
	 * @param tortue
	 * @see pModel.pTortue.Tortue
	 */
	public TortueLogo (Tortue tortue) { 
		this.tortue = tortue;	  
	};

	//
	// Methods
	//


	//
	// Accessor methods
	//

	//
	// Other methods
	//

	/* (non-Javadoc)
	 * @see pVue.pGUI.pLogo._Logo#draw(java.awt.Graphics)
	 */
	@Override
	public void draw( Graphics graph )
	{
		if (graph==null)
			return;	
		//Calcule les 3 coins du triangle a partir de
		// la position de la tortue p
		Point p = new Point(tortue.getX(),tortue.getY());
		Polygon arrow = new Polygon();

		//Calcule des deux bases
		//Angle de la droite
		double theta=ratioDegRad*(-tortue.getDirection());
		//Demi angle au sommet du triangle
		double alpha=Math.atan( (float)rb / (float)rp );
		//Rayon de la fleche
		double r=Math.sqrt( rp*rp + rb*rb );
		//Sens de la fleche

		//Pointe
		Point p2=new Point((int) Math.round(p.x+r*Math.cos(theta)),
				(int) Math.round(p.y-r*Math.sin(theta)));
		arrow.addPoint(p2.x,p2.y);
		arrow.addPoint((int) Math.round( p2.x-r*Math.cos(theta + alpha) ),
				(int) Math.round( p2.y+r*Math.sin(theta + alpha) ));

		//Base2
		arrow.addPoint((int) Math.round( p2.x-r*Math.cos(theta - alpha) ),
				(int) Math.round( p2.y+r*Math.sin(theta - alpha) ));

		arrow.addPoint(p2.x,p2.y);
		graph.setColor(tortue.getCouleur());
		graph.fillPolygon(arrow);
	}
}
