/**
 *
 * Copyright (C) 2012 Olivier Berthier
 *                    http://www.xunil.fr
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/

package pVue.pGUI.pTerrain;

import java.awt.Color;
import java.awt.Graphics;
import java.util.ArrayList;
import java.util.Iterator;

import javax.swing.JPanel;

import pModel.pTerrain.Terrain;
import pVue.pGUI.pLogo._Logo;

/**
 * Class TerrainJP
 * Permet de dessiner un terrain (JPanel).
 * 
 * @author Berthier Olivier
 *
 */
public class TerrainJP extends JPanel {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	/**
	 * Liste des logos à dessiner sur le TerrainJP 
	 */
	private ArrayList<_Logo> logos = new ArrayList<_Logo>();
	/**
	 * Constructeur de TerrainJP
	 * 
	 * @param Terrain
	 */
	public TerrainJP(Terrain terrain){		
		setBackground(new java.awt.Color(255, 255, 255));
		setBackground(Color.white);
		setSize(new java.awt.Dimension((int)terrain.getWidth(),(int)terrain.getHeight()));
		setPreferredSize(new java.awt.Dimension((int)terrain.getWidth(),(int)terrain.getHeight()));
	}
	/**
	 * Add a Logo object to the logoVector List
	 */
	public void addLogo ( _Logo new_object ) {
		logos.add( new_object);
	}

	/**
	 * Remove a Logo object from logoVector List
	 */
	public void removeLogo ( _Logo new_object )
	{
		logos.remove(new_object);
	}

	/**
	 * Retourne la liste des logos à dessiner
	 * @return List of Logo objects held by logoVector
	 */
	public ArrayList<_Logo> getLogos ( ) {
		return logos;
	}

	/**
	 * Défini la liste des logos à dessiner
	 * 
	 * @param logos
	 */
	public void setLogos(ArrayList<_Logo> logos){
		this.logos=logos;
	}

	/**
	 * Dessine les logos de la liste sur un objet de type Graphics passé en paramètre
	 * 
	 * @param g Graphics
	 */
	public void draw( Graphics g) {
		for(Iterator<_Logo> it = logos.iterator();it.hasNext();) {
			_Logo l = (_Logo) it.next();
			if(l!=null)
				l.draw(g);	
		}		
	}

	/* (non-Javadoc)
	 * @see javax.swing.JComponent#paintComponent(java.awt.Graphics)
	 */
	public void paintComponent(Graphics g) {		
		super.paintComponent(g);
		draw(g);		
	}
}
